==> quanyi-center-api-1.3.34-act-20250430.055946-4-sources.jar: cn/com/duiba/quanyi/center/api/remoteservice/activity/RemoteActivityBlackWhiteListService.java <==
package cn.com.duiba.quanyi.center.api.remoteservice.activity;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.quanyi.center.api.dto.activity.ActivityBlackWhiteListDto;
import cn.com.duiba.quanyi.center.api.param.activity.ActivityBlackWhiteListSearchParam;
import java.util.List;
import java.util.Set;

/**
 * 活动黑白名单表
 * @author kjj mybatis generator 
 * @date 2025-04-15
 */
@AdvancedFeignClient
public interface RemoteActivityBlackWhiteListService {
     
    /**
     * 根据条件查询，分页，管理后端列表查询专用
     * @param param 查询条件
     * @return 活动黑白名单集合
     */
    List<ActivityBlackWhiteListDto> selectPage(ActivityBlackWhiteListSearchParam param);

    /**
     * 根据条件,查询记录的总记录数
     * @param param 查询条件
     * @return 符合条件的记录数
     */
    long selectCount(ActivityBlackWhiteListSearchParam param);

    /**
     * 根据用户活动ID查询
     * @param userMark 用户唯一标记
     * @param activityId 活动ID
     * @return 活动黑白名单
     */
    List<ActivityBlackWhiteListDto> selectByUserActIdCache(String userMark, Long activityId);

    /**
     * 根据主键查询
     * @param id 主键
     * @return 活动黑白名单
     */
    ActivityBlackWhiteListDto selectById(Long id);

    /**
     * 新增
     * @param dto 活动黑白名单
     * @return 执行结果
     */
    int insert(ActivityBlackWhiteListDto dto);

    /**
     * 更新
     * @param dto 活动黑白名单
     * @return 影响行数
     */
    int update(ActivityBlackWhiteListDto dto);

    /**
     * 删除
     *
     * @param id           主键
     * @param operatorType 操作人类型
     * @param operatorId   操作人id
     * @param operatorName 操作人名字
     * @return 执行结果
     */
    int delete(Long id, Integer operatorType, Long operatorId, String operatorName);
}

==> quanyi-center-api-1.3.36-act-20250515.064133-19-sources.jar: cn/com/duiba/quanyi/center/api/remoteservice/activity/RemoteActivityBlackWhiteListService.java <==
package cn.com.duiba.quanyi.center.api.remoteservice.activity;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.quanyi.center.api.dto.activity.ActivityBlackWhiteListDto;
import cn.com.duiba.quanyi.center.api.dto.activity.common.cache.ActivityBlackWhiteListCacheDto;
import cn.com.duiba.quanyi.center.api.param.activity.ActivityBlackWhiteListSearchParam;

import javax.annotation.Nullable;
import java.util.List;
import java.util.Set;

/**
 * 活动黑白名单表
 * @author kjj mybatis generator 
 * @date 2025-04-15
 */
@AdvancedFeignClient
public interface RemoteActivityBlackWhiteListService {
     
    /**
     * 根据条件查询，分页，管理后端列表查询专用
     * @param param 查询条件
     * @return 活动黑白名单集合
     */
    List<ActivityBlackWhiteListDto> selectPage(ActivityBlackWhiteListSearchParam param);

    /**
     * 根据条件,查询记录的总记录数
     * @param param 查询条件
     * @return 符合条件的记录数
     */
    long selectCount(ActivityBlackWhiteListSearchParam param);

    /**
     * 根据用户活动ID查询
     * @param userMark 用户唯一标记
     * @param activityId 活动ID
     * @return 活动黑白名单
     */
    List<ActivityBlackWhiteListCacheDto> selectByUserActIdCache(String userMark, Long activityId);

    /**
     * 根据用户活动ID查询(仅仅走redis，redis中没有返回null)
     * @param userMark 用户唯一标记
     * @param activityId 活动ID
     * @return 活动黑白名单
     */
    @Nullable
    List<ActivityBlackWhiteListCacheDto> selectByUserActIdOnlyCache(String userMark, Long activityId);

    /**
     * 根据主键查询
     * @param id 主键
     * @return 活动黑白名单
     */
    ActivityBlackWhiteListDto selectById(Long id);

    /**
     * 新增
     * @param dto 活动黑白名单
     * @return 执行结果
     */
    int insert(ActivityBlackWhiteListDto dto);

    /**
     * 更新
     * @param dto 活动黑白名单
     * @return 影响行数
     */
    int update(ActivityBlackWhiteListDto dto);

    /**
     * 删除
     *
     * @param id           主键
     * @param operatorType 操作人类型
     * @param operatorId   操作人id
     * @param operatorName 操作人名字
     * @return 执行结果
     */
    int delete(Long id, Integer operatorType, Long operatorId, String operatorName);
}
